@@ -18,7 +18,7 @@ service corosync stop
 
 crm cluster init --yes --name=autopkgtest --unicast
 
-crm cluster geo-init --yes --clusters=autopkgtest=127.2.2.2 --tickets=ticket1
+crm cluster geo_init --yes --clusters=autopkgtest=127.2.2.2 --tickets=ticket1
 crm resource start g-booth
 sleep 5
 
